@@ -5,7 +5,7 @@
  *  Rodrigo Moya <rodrigo@ximian.com>
  *  Harish Krishnaswamy <kharish@novell.com>
  *
- * Copyright 2003, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -246,6 +246,8 @@ populate_cache (ECalBackendGroupwise *cbgw)
 			forward = FALSE;
 		}
 
+		e_cal_backend_notify_view_progress_start (E_CAL_BACKEND (cbgw));
+
 		while (!done) {
 
 			status = e_gw_connection_read_cursor (priv->cnc, priv->container_id, cursor, forward, CURSOR_ITEM_LIMIT, position, &list);
@@ -537,13 +539,13 @@ get_deltas (gpointer handle)
 		const char *recur_key;
 
 		if (calid->recur_key && calid->ical_id) {
-			const char *rid = NULL;
+			char *rid = NULL;
 			char *temp = NULL;
 			icaltimetype tt = icaltime_from_string (calid->ical_id);
 			if (!tt.is_date) {
 				tt = icaltime_convert_to_zone (tt, priv->default_zone);
 				icaltime_set_timezone (&tt, priv->default_zone);
-				rid = icaltime_as_ical_string (tt);
+				rid = icaltime_as_ical_string_r (tt);
 				temp = rid;
 			} else
 				rid = calid->ical_id;
@@ -628,6 +630,7 @@ get_deltas (gpointer handle)
 
 	e_file_cache_thaw_changes (E_FILE_CACHE (cache));
 
+	g_ptr_array_foreach (uid_array, (GFunc) g_free, NULL);
 	g_ptr_array_free (uid_array, TRUE);
 
 	if (item_list) {
@@ -747,7 +750,7 @@ start_fetch_deltas (gpointer data)
 	return FALSE;
 }
 
-
+#if 0
 /* TODO call it when a user presses SEND/RECEIVE or refresh*/
 static void
 e_cal_backend_groupwise_refresh_calendar (ECalBackendGroupwise *cbgw)
@@ -766,6 +769,7 @@ e_cal_backend_groupwise_refresh_calendar (ECalBackendGroupwise *cbgw)
 	if (!delta_started)
 		g_cond_signal (priv->dlock->cond);
 }
+#endif
 
 static char*
 form_uri (ESource *source)
@@ -1570,7 +1574,7 @@ e_cal_backend_groupwise_get_timezone (ECalBackendSync *backend, EDataCal *cal, c
         if (!icalcomp)
                 return GNOME_Evolution_Calendar_InvalidObject;
 
-        *object = icalcomponent_as_ical_string (icalcomp);
+        *object = icalcomponent_as_ical_string_r (icalcomp);
 
         return GNOME_Evolution_Calendar_Success;
 }
@@ -2577,8 +2581,12 @@ receive_object (ECalBackendGroupwise *cbgw, EDataCal *cal, icalcomponent *icalco
 				e_cal_component_free_id (id);
 			} else {
 				char *comp_str = NULL;
+				ECalComponentTransparency transp;
 
 				change_status (component, pstatus, e_gw_connection_get_user_email (priv->cnc));
+				e_cal_component_get_transparency (comp, &transp);
+				e_cal_component_set_transparency (component, transp);
+				
 				e_cal_backend_cache_put_component (priv->cache, component);
 				comp_str = e_cal_component_get_as_string (component);
 
