@@ -4,20 +4,20 @@
  *
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
- * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -25,17 +25,18 @@
 #include <config.h>
 #endif
 
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <string.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include "camel-stream-buffer.h"
 
 static CamelStreamClass *parent_class = NULL;
 
 enum {
-	BUF_USER = 1<<0,	/* user-supplied buffer, do not free */
+	BUF_USER = 1<<0	/* user-supplied buffer, do not free */
 };
 
 #define BUF_SIZE 1024
@@ -79,7 +80,7 @@ camel_stream_buffer_init (gpointer object, gpointer klass)
 	sbf->ptr = sbf->buf;
 	sbf->end = sbf->buf;
 	sbf->mode = CAMEL_STREAM_BUFFER_READ | CAMEL_STREAM_BUFFER_BUFFER;
-	sbf->stream = 0;
+	sbf->stream = NULL;
 	sbf->linesize = 80;
 	sbf->linebuf = g_malloc(sbf->linesize);
 }
@@ -125,7 +126,7 @@ set_vbuf(CamelStreamBuffer *sbf, char *buf, CamelStreamBufferMode mode, int size
 		g_free(sbf->buf);
 	}
 	if (buf) {
-		sbf->buf = buf;
+		sbf->buf = (unsigned char *) buf;
 		sbf->flags |= BUF_USER;
 	} else {
 		sbf->buf = g_malloc(size);
@@ -167,7 +168,7 @@ init(CamelStreamBuffer *sbuf, CamelStream *s, CamelStreamBufferMode mode)
  * See #camel_stream_buffer_new_with_vbuf for details on the
  * @mode parameter.
  *
- * Returns a newly created buffered stream.
+ * Returns: a newly created buffered stream.
  **/
 CamelStream *
 camel_stream_buffer_new (CamelStream *stream, CamelStreamBufferMode mode)
@@ -252,7 +253,7 @@ stream_read (CamelStream *stream, char *buffer, size_t n)
 					bptr += bytes_read;
 				}
 			} else {
-				bytes_read = camel_stream_read(sbf->stream, sbf->buf, sbf->size);
+				bytes_read = camel_stream_read(sbf->stream, (char *) sbf->buf, sbf->size);
 				if (bytes_read>0) {
 					size_t bytes_used = bytes_read > n ? n : bytes_read;
 					sbf->ptr = sbf->buf;
@@ -311,7 +312,7 @@ stream_write (CamelStream *stream, const char *buffer, size_t n)
 
 	/* if we've filled the buffer, write it out, reset buffer */
 	if (left == todo) {
-		if (stream_write_all(sbf->stream, sbf->buf, sbf->size) == -1)
+		if (stream_write_all(sbf->stream, (const char *) sbf->buf, sbf->size) == -1)
 			return -1;
 
 		sbf->ptr = sbf->buf;
@@ -338,10 +339,10 @@ stream_flush (CamelStream *stream)
 
 	if ((sbf->mode & CAMEL_STREAM_BUFFER_MODE) == CAMEL_STREAM_BUFFER_WRITE) {
 		size_t len = sbf->ptr - sbf->buf;
-		
-		if (camel_stream_write (sbf->stream, sbf->buf, len) == -1)
+
+		if (camel_stream_write (sbf->stream, (const char *) sbf->buf, len) == -1)
 			return -1;
-		
+
 		sbf->ptr = sbf->buf;
 	} else {
 		/* nothing to do for read mode 'flush' */
@@ -380,7 +381,7 @@ stream_eos (CamelStream *stream)
  * If the newline character is encountered, then it will be
  * included in the buffer @buf.  The buffer will be #NUL terminated.
  *
- * Returns the number of characters read, or %0 for end of file,
+ * Returns: the number of characters read, or %0 for end of file,
  * and %-1 on error.
  **/
 int
@@ -390,8 +391,8 @@ camel_stream_buffer_gets(CamelStreamBuffer *sbf, char *buf, unsigned int max)
 	int bytes_read;
 
 	outptr = buf;
-	inptr = sbf->ptr;
-	inend = sbf->end;
+	inptr = (char *) sbf->ptr;
+	inend = (char *) sbf->end;
 	outend = buf+max-1;	/* room for NUL */
 
 	do {
@@ -400,25 +401,27 @@ camel_stream_buffer_gets(CamelStreamBuffer *sbf, char *buf, unsigned int max)
 			*outptr++ = c;
 			if (c == '\n') {
 				*outptr = 0;
-				sbf->ptr = inptr;
+				sbf->ptr = (unsigned char *) inptr;
 				return outptr-buf;
 			}
 		}
 		if (outptr == outend)
 			break;
 
-		bytes_read = camel_stream_read (sbf->stream, sbf->buf, sbf->size);
+		bytes_read = camel_stream_read (sbf->stream, (char *) sbf->buf, sbf->size);
 		if (bytes_read == -1) {
 			if (buf == outptr)
 				return -1;
 			else
 				bytes_read = 0;
 		}
-		inptr = sbf->ptr = sbf->buf;
-		inend = sbf->end = sbf->buf + bytes_read;
+		sbf->ptr = sbf->buf;
+		sbf->end = sbf->buf + bytes_read;
+		inptr = (char *) sbf->ptr;
+		inend = (char *) sbf->end;
 	} while (bytes_read>0);
 
-	sbf->ptr = inptr;
+	sbf->ptr = (unsigned char *) inptr;
 	*outptr = 0;
 
 	return (int)(outptr - buf);
@@ -432,7 +435,7 @@ camel_stream_buffer_gets(CamelStreamBuffer *sbf, char *buf, unsigned int max)
  * and returns it in allocated memory. The trailing newline (and carriage
  * return if any) are not included in the returned string.
  *
- * Returns the line read, which the caller must free when done with,
+ * Returns: the line read, which the caller must free when done with,
  * or %NULL on eof. If an error occurs, @ex will be set.
  **/
 char *
@@ -444,7 +447,7 @@ camel_stream_buffer_read_line (CamelStreamBuffer *sbf)
 	p = sbf->linebuf;
 
 	while (1) {
-		nread = camel_stream_buffer_gets (sbf, p, sbf->linesize - (p - sbf->linebuf));
+		nread = camel_stream_buffer_gets (sbf, (char *) p, sbf->linesize - (p - sbf->linebuf));
 		if (nread <=0) {
 			if (p > sbf->linebuf)
 				break;
@@ -466,5 +469,5 @@ camel_stream_buffer_read_line (CamelStreamBuffer *sbf)
 		p--;
 	p[0] = 0;
 
-	return g_strdup(sbf->linebuf);
+	return g_strdup((char *) sbf->linebuf);
 }
