@@ -258,6 +258,26 @@ check_for_connection (CamelService *service, CamelException *ex)
 
 }
 
+/* resets the current folder. To just free current folder, pass NULL for folder */
+void
+groupwise_store_set_current_folder (CamelGroupwiseStore *groupwise_store, CamelFolder *folder)
+{
+		
+	CAMEL_SERVICE_REC_LOCK (groupwise_store, connect_lock);
+	
+	if (groupwise_store->current_folder) {
+		camel_object_unref (groupwise_store->current_folder);
+		groupwise_store->current_folder = NULL;
+	}
+
+	if (folder) {
+		camel_object_ref (folder);
+		groupwise_store->current_folder = folder;
+	}
+	
+	CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
+}
+
 static gboolean
 groupwise_connect (CamelService *service, CamelException *ex)
 {
@@ -390,6 +410,9 @@ groupwise_disconnect (CamelService *service, gboolean clean, CamelException *ex)
 			g_object_unref (groupwise_store->priv->cnc);
 			groupwise_store->priv->cnc = NULL;
 		}
+
+		groupwise_store_set_current_folder (groupwise_store, NULL);
+
 		CAMEL_SERVICE_REC_UNLOCK (groupwise_store, connect_lock);
 	}
 	
@@ -462,7 +485,11 @@ groupwise_build_folder_info(CamelGroupwiseStore *gw_store, const char *parent_na
 		fi->flags |= CAMEL_FOLDER_TYPE_TRASH;
 	else if (!strcmp (folder_name, "Junk Mail"))
 		fi->flags |= CAMEL_FOLDER_TYPE_JUNK;
-		
+
+	if (groupwise_is_system_folder (folder_name))
+		fi->flags |= CAMEL_FOLDER_SYSTEM;
+	
+
 	fi->name = g_strdup(name);
 	return fi;
 }
@@ -543,7 +570,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 	
 	folder = groupwise_get_folder_from_disk (store, folder_name, flags, ex);
 	if (folder) {
-		camel_object_ref (folder);
+		groupwise_store_set_current_folder (gw_store, folder);
 		return folder;
 	}
 
@@ -551,16 +578,13 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 
 	CAMEL_SERVICE_REC_LOCK (gw_store, connect_lock);
 
+	groupwise_store_set_current_folder (gw_store, NULL);
+
 	if (!camel_groupwise_store_connected (gw_store, ex)) {
 		CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 		return NULL;
 	}
 	
-	if (gw_store->current_folder) {
-		camel_object_unref (gw_store->current_folder);
-		gw_store->current_folder = NULL;
-	}
-
 	if (!E_IS_GW_CONNECTION( priv->cnc)) {
 		if (!groupwise_connect (CAMEL_SERVICE(store), ex)) {
 			CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
@@ -667,8 +691,7 @@ groupwise_get_folder (CamelStore *store, const char *folder_name, guint32 flags,
 
 	camel_folder_summary_save_to_db (folder->summary, ex);
 
-	gw_store->current_folder = folder;
-	camel_object_ref (folder);
+	groupwise_store_set_current_folder (gw_store, folder);
 
 	g_free (container_id);
 	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
@@ -787,7 +810,7 @@ gw_store_reload_folder (CamelGroupwiseStore *gw_store, CamelFolder *folder, guin
 
 	camel_folder_summary_save_to_db (folder->summary, ex);
 
-	gw_store->current_folder = folder;
+	groupwise_store_set_current_folder (gw_store, NULL);
 	
 	g_free (container_id);
 	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
@@ -1284,6 +1307,12 @@ groupwise_delete_folder(CamelStore *store,
 
 	CAMEL_SERVICE_REC_LOCK (store, connect_lock);
 
+	if (groupwise_is_system_folder (folder_name)) {
+		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot delete GroupWise system folder '%s'"),
+				      folder_name);
+		return;
+	}
+
 	if (!camel_groupwise_store_connected (groupwise_store, ex)) {
 		CAMEL_SERVICE_REC_UNLOCK (store, connect_lock);
 		return;
@@ -1294,8 +1323,7 @@ groupwise_delete_folder(CamelStore *store,
 	status = e_gw_connection_remove_item (priv->cnc, container, container);
 
 	if (status == E_GW_CONNECTION_STATUS_OK) {
-		if (groupwise_store->current_folder)
-			camel_object_unref (groupwise_store->current_folder);
+		groupwise_store_set_current_folder (groupwise_store, NULL);
 
 		groupwise_forget_folder(groupwise_store,folder_name,ex);
 
@@ -1332,6 +1360,8 @@ groupwise_rename_folder(CamelStore *store,
 		return;
 	}
 
+	groupwise_store_set_current_folder (groupwise_store, NULL);
+
 	container_id = camel_groupwise_store_container_id_lookup (groupwise_store, old_name);
 	temp_new = strrchr (new_name, '/');
 	if (temp_new)
@@ -1430,6 +1460,17 @@ groupwise_get_trash (CamelStore *store, CamelException *ex)
 		return NULL;
 }
 
+static gboolean
+groupwise_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelException *ex)
+{
+	gboolean res;
+
+	res = CAMEL_STORE_CLASS(parent_class)->can_refresh_folder (store, info, ex) ||
+	      (camel_url_get_param (((CamelService *)store)->url, "check_all") != NULL);
+
+	return res;
+}
+
 /*
  * Function to check if we are both connected and are _actually_
  * online. Based on an equivalient function in IMAP
@@ -1498,6 +1539,7 @@ camel_groupwise_store_class_init (CamelGroupwiseStoreClass *camel_groupwise_stor
 	camel_store_class->get_folder_info = groupwise_get_folder_info;
 	camel_store_class->free_folder_info = camel_store_free_folder_info_full;
 	camel_store_class->get_trash = groupwise_get_trash;
+	camel_store_class->can_refresh_folder = groupwise_can_refresh_folder;
 }
 
 
@@ -1575,6 +1617,7 @@ camel_groupwise_store_init (gpointer object, gpointer klass)
 	priv->user = NULL;
 	priv->cnc = NULL;
 	groupwise_store->priv = priv;
+	groupwise_store->current_folder = NULL;
 	
 }
 
@@ -1597,3 +1640,4 @@ camel_groupwise_store_get_type (void)
 	
 	return camel_groupwise_store_type;
 }
+
