@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Novell Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors:
  *	parthasarathi susarla <sparthasarathi@novell.com>
@@ -56,11 +56,11 @@ struct _CamelGroupwiseMessageContentInfo {
 
 
 struct _CamelGroupwiseSummary {
-	CamelFolderSummary parent ;
+	CamelFolderSummary parent;
 
 	char *time_string;
-	guint32 version ;
-	guint32 validity ;
+	gint32 version;
+	gint32 validity;
 } ;
 
 
